@@ -53,8 +53,11 @@ class SSHClient(object):
                 timeout=self.__connect_timeout
             )
             return True
+        except paramiko.ssh_exception.SSHException as e:
+            log.warning(f"{self.__ip}:{self.__port} | cannot create ssh session.")
+            return False
         except Exception as e:
-            log.warning(f"{self.__ip}:{self.__port} | server is not sshable.", exc_info=True)
+            log.warning(f"{self.__ip}:{self.__port} | server is not sshable.")
             return False
         finally:
             ssh.close()
